<?php

/**
 * Métrologie
 * Envoie d'informations sur un serveur influxdb
 * Si le fichier metrics.conf est bien renseigné
 */
require_once ("config.inc.php");
$config = get_config();
require_once ("functions.inc.php");
require_once ("logs.inc.php");
require_once ("ldap.inc.php");
require_once ("/var/www/sambaedu/vendor/autoload.php");
header_authorize_script($config);

$success = false;
apcu_fetch('metrics_lock', $success);
if ($success) {
    exit();
}
apcu_add('metrics_lock', 300);

// lit le fichier de conf ou sort
$token = $config['influxdb_token'] ?? exit();
$influxdb_url = $config['influxdb_url'] ?? exit();
$org = $config['influxdb_org'] ?? exit();
$bucket = $config['influxdb_bucket'] ?? exit();

use InfluxDB2\Client;
use InfluxDB2\Model\WritePrecision;
use InfluxDB2\Point;

$client = new Client([
    "url" => $influxdb_url,
    "token" => $token
]);

$writeApi = $client->createWriteApi();
$UAI = $config['UAI'] ?? "";
$host = $UAI;
//Ajout des IP en longint
$se4fs_ip = ip2long($config['se4fs_ip']) ?? "";
$se4ad_ip = ip2long($config['se4ad_ip']) ?? "";
// Compte le nombre de sessions ouvertes
$smb_login = open_sessions($config);
$nbusersconnected = count($smb_login);

// Utilisation de apcu en cache pour le nombre total d'utilisateurs
$success = false;
$nbusers = apcu_fetch('metrics_nbusers', $success);
if (! $success) {
    $nbusers = count(search_ad($config, "*", "user", $config['dn']['people']));
    apcu_add('metrics_nbusers', $nbusers, 1000);
}

// cpu, ram, nbcomputers
$cpuload = `cat /proc/loadavg | cut -f1 -d" "`;
$ramused = `free -m | grep "Mem" | awk '{print 100*(1-($4+$6)/$2)}'`;
$computers = count(search_ad($config, "*", "computers", $config['dn']['computers']));

// Partitions
$PartHome = `df -h | grep "/home" | awk {'print $5'} | cut -d"%" -f1`;
$PartSambaedu = `df -h | grep "/sambaedu" | awk {'print $5'} | cut -d"%" -f1`;

// écriture en BDD
$data = "disks,host=$host home=$PartHome";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "disks,host=$host sambaedu=$PartSambaedu";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "users,host=$host nbusers=$nbusers";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "users,host=$host nbusersconnected=$nbusersconnected";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "cpu,host=$host cpuload=$cpuload";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "ram,host=$host ramused=$ramused";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "computers,host=$host nbcomputers=$computers";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "IP,host=$host se4ad_ip=$se4ad_ip";
$writeApi->write($data, WritePrecision::S, $bucket, $org);

$data = "IP,host=$host se4fs_ip=$se4fs_ip";
$writeApi->write($data, WritePrecision::S, $bucket, $org);



$client->close();

apcu_delete('metrics_lock');
?>